@@ -86,7 +86,7 @@
 #define PLASMA_BUILD_DEPRECATED_SINCE(major, minor) 1
 
 #ifdef PLASMA_NO_DEPRECATED
-#  define PLASMA_DISABLE_DEPRECATED_BEFORE_AND_AT 0x54100
+#  define PLASMA_DISABLE_DEPRECATED_BEFORE_AND_AT 0x54800
 #endif
 #ifdef PLASMA_NO_DEPRECATED_WARNINGS
 #  define PLASMA_DEPRECATED_WARNINGS_SINCE 0
@@ -96,7 +96,7 @@
 #  ifdef PLASMA_DISABLE_DEPRECATED_BEFORE_AND_AT
 #    define PLASMA_DEPRECATED_WARNINGS_SINCE PLASMA_DISABLE_DEPRECATED_BEFORE_AND_AT
 #  else
-#    define PLASMA_DEPRECATED_WARNINGS_SINCE 0x54100
+#    define PLASMA_DEPRECATED_WARNINGS_SINCE 0x54800
 #  endif
 #endif
 
@@ -145,7 +145,14 @@
 #else
 #  define PLASMA_DEPRECATED_VERSION_5_46(text)
 #endif
+
+#if PLASMA_DEPRECATED_WARNINGS_SINCE >= 0x54300
+#  define PLASMA_DEPRECATED_VERSION_5_67(text) PLASMA_DECL_DEPRECATED_TEXT(text)
+#else
+#  define PLASMA_DEPRECATED_VERSION_5_67(text)
+#endif
 #define PLASMA_DEPRECATED_VERSION_5(minor, text)      PLASMA_DEPRECATED_VERSION_5_##minor(text)
 #define PLASMA_DEPRECATED_VERSION(major, minor, text) PLASMA_DEPRECATED_VERSION_##major(minor, "Since "#major"."#minor". " text)
+#define PLASMA_DEPRECATED_VERSION_BELATED(major, minor, textmajor, textminor, text) PLASMA_DEPRECATED_VERSION_##major(minor, "Since "#textmajor"."#textminor". " text)
 
 #endif /* PLASMA_EXPORT_H */
